@@ -27,19 +27,31 @@ def __getattr__(name: str) -> Any:
         return NewForm
     """
 
-    Form = OriginalClass.form
-    if not issubclass(Form, forms.FormMixin):
+    if Form := getattr(OriginalClass, "form"):
+        Form = OriginalClass.form
+        if not issubclass(Form, forms.FormMixin):
 
-        class NewForm(forms.FormMixin, Form):  # type: ignore
-            pass
+            class NewForm(forms.FormMixin, Form):  # type: ignore
+                pass
 
-        Form = NewForm
+            Form = NewForm
 
-    class NewAdmin(AdminMixin, OriginalClass):  # type: ignore
-        form = Form
+        class NewAdmin(AdminMixin, OriginalClass):  # type: ignore
+            form = Form
 
-    return NewAdmin
+        return NewAdmin
+
+    # no form attribute, so leave as-is
+    return OriginalClass
 
 
 class ModelAdmin(AdminMixin, admin.ModelAdmin):
     form = forms.ModelForm
+
+
+def register(*args, **kw):
+    """
+    You can use this in place of admin.site.register
+    with your nango-aware models
+    """
+    return admin.register(*args, **kw)
